from .def_fun import complete
from .def_fun_2nodes import complete2
from .def_fun_3nodes import complete3
from .def_fun_4nodes import complete4

# Declare global variable name for use in all functions
print('Write <<num_nodes("# of nodes - 1 to 4")>> eg - num_nodes(1) ')


# Define function to check if name contains a vowel
def num_nodes(name):
    if name==(1):
        complete()
        #exec(open("complete.py").read())
    elif name==(2):
        complete2()
    elif name==(3):
        complete3()
    elif name==(4):
        complete4()
    else:
        print('Not possible, 4 nodes is max (sharing is caring)')



# Define main method that calls other functions
def main():
    num_nodes()

# Execute main() function
if __name__ == '__main__':
    main()




import glob
import numpy as np
import pandas as pd
import os
#from .delete import deleting
import subprocess
import sys
from .delete import wrong


def analyze():
    wrong()
    my_path=(os.getcwd())
    print(my_path)
    filenames=glob.glob(my_path + '/*/md.log', recursive=True)
    filenames2=glob.glob(my_path + '/*/job_script_*', recursive=True)
    
    #x=[]
    #for f in filenames:
    #    outfile = open(f,'r')
    #    data = outfile.readlines()
    #    outfile.close()
    #    for line in data:
    #        if 'Performance:' in line:
    #            energy_line = line
    #            words = energy_line.split()
    #            energy = float(words[1])
    #            #print(energy)
    #            x.append(energy)
 
    x=[]
    
    for f in filenames:
        outfile = open(f,'r')
        data = outfile.readlines()
        outfile.close()
        for line in data:
            if 'Performance:' in line:
                energy_line = line
                words = energy_line.split()
                energy = float(words[1])
        u=[]
        u.append(energy)
    
        x.append(u)
       
    
    y=[]
    z=[]
    u=[]
    d=[]
    for f in filenames2:
        outfile2 = open(f,'r')
        data2 = outfile2.readlines()
        outfile2.close()
        for line in data2:
            if '--ntasks-per-node=' in line:
                energy_line2 = line
                words2 = energy_line2.split()
                energy2 = (words2[1])
                y.append(energy2)
            if '--cpus-per-task=' in line:
                energy_line3 = line
                words3 = energy_line3.split()
                energy3 = (words3[1])
                z.append(energy3)
            if '--gres=gpu:' in line:
                energy_line4 = line
                words4 = energy_line4.split()
                energy4 = (words4[1])
                u.append(energy4)
            if '--nodes=' in line:
                energy_line5 = line
                words5 = energy_line5.split()
                energy5 = (words5[1])
                d.append(energy5)
        
    df = pd.DataFrame(
    {'Perfomance': x,
     'Ntasks': y,
     'CPUs': z,
     'GPUs': u,
     'Nodes': d
    })
    df

    df['Ntasks'] = df['Ntasks'].astype(str).str.split('=').str[1]
    df['CPUs'] = df['CPUs'].astype(str).str.split('=').str[1]
    df['GPUs'] = df['GPUs'].astype(str).str.split(':').str[1]
    df['Nodes'] = df['Nodes'].astype(str).str.split('=').str[1]

    #pd.set_option('display.max_colwidth',1000)
    #pd.set_option('display.max_rows', df.shape[0]+1)
    pd.set_option('display.max_columns', None)
    pd.set_option('display.expand_frame_repr', False)
    pd.set_option('max_colwidth', -1)

    df = df.sort_values(by=['Perfomance'], ascending=False)
    df = df.reset_index()
    df = df.reset_index(drop=True)
    df_new=df.drop(['index'],axis=1)
    with open('./Benchmark_Perfomance.png', 'a') as fo:
        fo.write(df_new.__repr__())

    print('DONE!')



from subprocess import call
import time
import subprocess
from .benchmark_1gpu_fun import Benchmark_1gpu
from .benchmark_2gpu_fun import Benchmark_2gpu
from .benchmark_3gpu_fun import Benchmark_3gpu
from .benchmark_6gpu_fun import Benchmark_6gpu
from .benchmark_12gpu_fun import Benchmark_12gpu
from .benchmark_18gpu_fun import Benchmark_18gpu

from .time import time_count
from .analysis import analyze


def complete4():
    subprocess.check_call('module purge; module load anaconda', shell=True)
    
    Benchmark_1gpu()
    Benchmark_2gpu()
    Benchmark_3gpu()
    Benchmark_6gpu()
    Benchmark_12gpu()
    Benchmark_18gpu()

    subprocess.check_call('for x in ./*; do mkdir "${x}".d && mv "$x" "${x}".d; done;for f in *.d; do mv -n -- "$f" "${f%.d}"; done;for file in job_*; do mv "$file" "${file#job_}";done;for i in ./*; do cp ../*.tpr ${i}/; done;for d in ./*/ ; do (cd "$d" && sbatch job_script*); done',shell=True)
    subprocess.check_call('squeue -n bingo > file.txt', shell=True)
    
    time_count()
    analyze()
    
                          
    analyze()
    



from subprocess import call
import time
import subprocess
import os


def time_count():
    def check():
        with open('file.txt') as f:
        #with open(os.path.join(os.path.dirname(__file__), 'file.txt')) as f:
            datafile = f.readlines()
        found = False  # This isn't really necessary
        for line in datafile:
            if ('bingo') in line:
                # found = True # Not necessary
                return True
        return False  # Because you finished the search without finding


    while True:
        if check():
            x=('False')
            subprocess.check_call('squeue -n bingo > file.txt', shell=True)
            time.sleep(10.4)
        else:
            y=('True')
            #subprocess.check_call('squeue -n bingo > file.txt', shell=True)
            break



import subprocess
import os
#from .delete import deleting
import subprocess
import sys
import glob

def wrong():
    with open('md.log', 'w') as f:
        f.write('Performance:       0.00        0.00' + "\n")
        f.close
    
    subprocess.check_call('for i in script_*;do cp -vn md.log ${i}/;done', shell=True)
    my_path=(os.getcwd())
    filenames=glob.glob(my_path + '/*/md.log', recursive=True)
    for f in filenames:
        with open(f, 'r') as original: data = original.read()
        with open(f, 'w') as modified: modified.write("Performance:       0.00        0.00\n" + data)



from distutils.core import setup

setup(name='phys_benchmark',
      version='2.1',
      description='Benchamrking MD on PHYS MPU cluster',
      author='Adelie Louet',
      author_email='adelie.louet@biophys.mpg.de',
      url='https://github.com/louetadelie1/benchmark_phys.git/',
      packages=[],
     )



#!/usr/bin/env python
# coding: utf-8

# In[ ]:


import math
import numpy as np
import itertools



###for 2 GPU and 1 node

import itertools
import pandas as pd


# In[ ]:


def Benchmark_1gpu():
    list_one = list((range(1, 19)))
    list_two =list((range(1, 19)))
    result = itertools.product(list_one, list_two)
    df=pd.DataFrame(result, columns=['ntasks', 'cpu'])
    df['cores'] = df['ntasks'] * df['cpu']
    df = df.drop(df[df.cores >= 18].index)
    df = df.drop(df[df.cpu == 1].index)

    x=len(df.index)
    run = range(0,int(x))
    df['run'] = run


    for index, row in df.iterrows():
        with open("job_script_1_" + (str(row["run"])), "w") as f:
            f.write(
                    "#!/bin/bash -l" +  "\n"
                    "# Standard output and error:" +  "\n"
                    "#SBATCH -o ./bench.out.%j"+  "\n"
                    "#SBATCH -e ./bench.err.%j"+  "\n"
                    "# Initial working directory:"+  "\n"
                    "#SBATCH -D ./"+  "\n"
                    "#"+  "\n"
                    "#SBATCH -J bingo"+  "\n"
                    "#"+  "\n"
                    "# Queue:" +  "\n"
                    "#SBATCH --partition=s.phys" + "\n"
                    "#SBATCH --gres=gpu:1"+  "\n"
                    "# Request 10 nodes"+  "\n"
                    "#SBATCH --nodes=1"+  "\n"
                    "# Set the number of tasks per node (=MPI ranks)"+  "\n"
                    "#SBATCH --ntasks-per-node=" + str(row["ntasks"]) + "\n"
                    "# Set the number of threads per rank (=OpenMP threads)"+  "\n"
                    "#SBATCH --cpus-per-task="+ str(row["cpu"]) + "\n"
                    "# Explicitly disable hyperthreading"+  "\n"
                    "#SBATCH --ntasks-per-core=1" + "\n"
                    "#SBATCH --mem=62000" + "\n"
                    "#SBATCH --time=01:00:00" + "\n"
                    "" + "\n"
                    "module purge" + "\n"
                    "module load intel/19.1.3"+  "\n"
                    "module load impi/2019.9"+  "\n"
                    "module load cuda/11.4"+  "\n"
                    "module load anaconda" + "\n"
                    "module load gcc/10" + "\n"
                    "module load gromacs/2021.5"+  "\n"
                    ""+  "\n"
                    "export OMP_NUM_THREADS=$SLURM_CPUS_PER_TASK"+  "\n"
                    "export OMP_PLACES=cores"+  "\n"
                    ""+  "\n"

                    "srun gmx_mpi mdrun -v -s *.tpr -ntomp $OMP_NUM_THREADS -pme gpu -npme 1 -pmefft gpu -bonded gpu -nb gpu -maxh 0.25"+  "\n"
        )
        f.close()

